#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 ghcide
version:              2.2.0.0
visibility:           public
id:                   ghcide-2.2.0.0-CSpouCprknHIonWWwzoGG
key:                  ghcide-2.2.0.0-CSpouCprknHIonWWwzoGG
license:              Apache-2.0
copyright:            Digital Asset and Ghcide contributors 2018-2020
maintainer:           Ghcide contributors
author:               Digital Asset and Ghcide contributors
homepage:
    https://github.com/haskell/haskell-language-server/tree/master/ghcide#readme

synopsis:             The core of an IDE
description:          A library for building Haskell IDE'\''s on top of the GHC API.
category:             Development
abi:                  12b78baa1c1ff99db12afe2e3040af76
exposed:              True
exposed-modules:
    Control.Concurrent.Strict Development.IDE
    Development.IDE.Core.Actions Development.IDE.Core.Compile
    Development.IDE.Core.Debouncer Development.IDE.Core.FileStore
    Development.IDE.Core.FileUtils
    Development.IDE.Core.IdeConfiguration
    Development.IDE.Core.OfInterest Development.IDE.Core.PluginUtils
    Development.IDE.Core.PositionMapping
    Development.IDE.Core.Preprocessor
    Development.IDE.Core.ProgressReporting
    Development.IDE.Core.RuleTypes Development.IDE.Core.Rules
    Development.IDE.Core.Service Development.IDE.Core.Shake
    Development.IDE.Core.Tracing Development.IDE.Core.UseStale
    Development.IDE.GHC.Compat Development.IDE.GHC.Compat.Core
    Development.IDE.GHC.Compat.Env Development.IDE.GHC.Compat.Iface
    Development.IDE.GHC.Compat.Logger
    Development.IDE.GHC.Compat.Outputable
    Development.IDE.GHC.Compat.Parser
    Development.IDE.GHC.Compat.Plugins Development.IDE.GHC.Compat.Units
    Development.IDE.GHC.Compat.Util Development.IDE.GHC.CoreFile
    Development.IDE.GHC.Error Development.IDE.GHC.Orphans
    Development.IDE.GHC.Util
    Development.IDE.Import.DependencyInformation
    Development.IDE.Import.FindImports
    Development.IDE.LSP.HoverDefinition
    Development.IDE.LSP.LanguageServer
    Development.IDE.LSP.Notifications Development.IDE.LSP.Outline
    Development.IDE.LSP.Server Development.IDE.Main
    Development.IDE.Main.HeapStats Development.IDE.Monitoring.EKG
    Development.IDE.Monitoring.OpenTelemetry Development.IDE.Plugin
    Development.IDE.Plugin.Completions
    Development.IDE.Plugin.Completions.Types Development.IDE.Plugin.HLS
    Development.IDE.Plugin.HLS.GhcIde Development.IDE.Plugin.Test
    Development.IDE.Plugin.TypeLenses Development.IDE.Session
    Development.IDE.Spans.AtPoint Development.IDE.Spans.Common
    Development.IDE.Spans.Documentation
    Development.IDE.Spans.LocalBindings Development.IDE.Spans.Pragmas
    Development.IDE.Types.Diagnostics Development.IDE.Types.Exports
    Development.IDE.Types.HscEnvEq Development.IDE.Types.KnownTargets
    Development.IDE.Types.Location Development.IDE.Types.Monitoring
    Development.IDE.Types.Options Development.IDE.Types.Shake
    Generics.SYB.GHC Text.Fuzzy.Parallel

hidden-modules:
    Development.IDE.Core.FileExists Development.IDE.GHC.CPP
    Development.IDE.GHC.Warnings
    Development.IDE.Plugin.Completions.Logic
    Development.IDE.Session.VersionCheck Development.IDE.Types.Action

import-dirs:          /usr/lib/ghc-9.6.6/site-local/ghcide-2.2.0.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/ghcide-2.2.0.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/ghcide-2.2.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-ghcide
hs-libraries:         HSghcide-2.2.0.0-CSpouCprknHIonWWwzoGG
depends:
    Diff-0.5-9iFzYwbbznxCTrvC5fevGO Glob-0.10.2-2ZMF3q0E9RcIvo0RuO2Ci6
    aeson-2.2.1.0-3GuQND0ICGU2GYmExSDp1b
    aeson-pretty-0.8.10-5vtA4EiaXNkLoXuiqNDeq8 array-0.5.6.0
    async-2.2.5-BExe3HBSFHr8hii1cT1bvS base-4.18.2.1
    base16-bytestring-1.0.2.0-4dU46p0HYXn6d3pnzwPlcc binary-0.8.9.1
    bytestring-0.11.5.3 case-insensitive-1.2.1.0-HFTLAepm1u61gRs0sAANH
    co-log-core-0.3.2.6-3vrwyvqVYJd1UovIolHFNX containers-0.6.7
    cryptohash-sha1-0.11.101.0-7DQRcWZzOWtDy5J4LraOTr
    data-default-0.7.1.3-EtVHsfbH5oIpJ9umzYHUz deepseq-1.4.8.1
    dependent-map-0.4.0.1-1hoe9QgIp9l6NGtg7waa59
    dependent-sum-0.7.2.0-AxUBC6fTAvp2mIqhniKxpx directory-1.3.8.5
    dlist-1.0-B7D1vsARFiIHVaGk5CGbYO
    enummapset-0.7.3.0-BNR0FcFQJBCw1Qv4bH0EV exceptions-0.10.7
    extra-1.7.16-6e0wBrlA2xu66mkOtGwbe0 filepath-1.4.300.1
    fingertree-0.1.6.2-9sjZ9Frt9NG3heH8Jby2UD
    focus-1.0.3.2-H56Npl315YpJ9rOb91MeHO ghc-9.6.6 ghc-boot-9.6.6
    ghc-boot-th-9.6.6 ghc-check-0.5.0.8-6jTTy9C1XqO7oi3STSyBWq
    ghc-paths-0.1.0.12-JSGGj7CcxjZ2Iy0LlOG5cZ
    ghc-trace-events-0.1.2.10-H26I0MYftT2GE85bySiIsN
    haddock-library-1.11.0-B8FeFNzhYVYFWRejMBvFFl
    hashable-1.4.7.0-LE3bCdm1Wgy6IgVYkRoAlQ
    hie-bios-0.12.0-IbTvOeZ0XBcGSSMQUuGghp
    hie-compat-0.3.1.2-37lTPgU0jdr1Ufn5QvEKoZ
    hiedb-0.4.3.0-8qFqqPGEVaMJvvvBqZwbN7
    hls-graph-2.2.0.0-I9PWN5GEmjKBAgfSbPrDBw
    hls-plugin-api-2.2.0.0-6YWL6LBFpzO4o9geFAjygf
    implicit-hie-0.1.4.0-4OdBi5qHgy3HfPVZnyoZ0i
    implicit-hie-cradle-0.5.0.1-1lW7YiCqsVS9GpvC8g7keC
    lens-5.3.3-Ag3JywAjDxJ2k98xBhf4hs
    list-t-1.0.5.7-2HoWk2ZeMET712yzW1kDHy
    lsp-2.2.0.0-GAelPC2nKQJ3Ee44oBrEuJ
    lsp-types-2.0.2.0-87S3u33tq1BDqfZjjAwcBC mtl-2.3.1
    opentelemetry-0.8.0-4DGPmn5BKVy9ubbkBxiTT0
    optparse-applicative-0.18.1.0-9I3qDpNxi1rBTnWffPMXX3
    parallel-3.2.2.0-4GFGhbl8Ae06nPoqdIyBUD
    prettyprinter-1.7.1-4PNEjQDcFkU8z4wKR8XxHs
    prettyprinter-ansi-terminal-1.1.3-16T9vhA2HoNHCC5fXPVq0T
    random-1.2.1.3-HzFGhfPSv5b3eeTVe0g48p
    regex-tdfa-1.3.2.5-4Nt33WWCOhH70pmXr5RVz
    row-types-1.0.1.2-1KPI2BY2URnDbZFtTY7TBE
    safe-exceptions-0.1.7.4-1N8osx2f6QPFEoh8MaW5LS
    sorted-list-0.2.3.1-B7chDh8YH97F9UBUowDtaN
    sqlite-simple-0.4.19.0-2gqJp3uuyPcIO0uWKTJuFn stm-2.5.1.0
    stm-containers-1.2.1.1-Ir2SRVdouP9G5ZwEZccrvL
    syb-0.7.3-HezvxMxFoxE4YYIFSuLToH text-2.0.2
    text-rope-0.3-8YuI8QHnRpR6wIaikFYuUd time-1.12.2
    transformers-0.6.1.0 unix-2.8.4.0
    unliftio-0.2.25.1-2Z0SKAH7tah9jbYwGNfwFX
    unliftio-core-0.2.1.0-6sOpIonHj8t5wIbPhWbPHY
    unordered-containers-0.2.20.1-I6eyTXb69D2BhxejMtPouo
    vector-0.13.2.0-KFVS0U8K6eML5O0P7tVbRi

haddock-interfaces:   /usr/share/doc/haskell-ghcide/html/ghcide.haddock
haddock-html:         /usr/share/doc/haskell-ghcide/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

